gokit

package module
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 5, 2018 License: MIT Imports: 0 Imported by: 0

README

GoKit

GoDoc

This repository contains useful code that we use in our Go projects.

Examples

web.Server
import (
	"log"
	"time"

	"github.com/moexmen/gokit/web"
)

func main() {
	s := web.Server{
		Addr:    ":8080",
		Timeout: 5 * time.Second,
	}
	log.Println("Starting...")
	log.Println(s.ListenAndServe())
}

If you use docker, docker stop has a default timeout of 10 seconds, the graceful timeout should be set to expire before then.

Documentation

Overview

Package gokit contains useful code that we use in our Go projects.

Directories

Path Synopsis

Jump to