package
module
Version:
v1.1.1
Opens a new window with list of versions in this module.
Published: Feb 5, 2018
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
GoKit

This repository contains useful code that we use in our Go projects.
Examples
web.Server
import (
"log"
"time"
"github.com/moexmen/gokit/web"
)
func main() {
s := web.Server{
Addr: ":8080",
Timeout: 5 * time.Second,
}
log.Println("Starting...")
log.Println(s.ListenAndServe())
}
If you use docker, docker stop has a default timeout of 10 seconds, the graceful timeout should be set to expire before then.
Documentation
¶
Package gokit contains useful code that we use in our Go projects.
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.